#!/usr/bin/env node
"use strict";

var _commander = _interopRequireDefault(require("commander"));

var _rest = _interopRequireDefault(require("@octokit/rest"));

var _package = _interopRequireDefault(require("../../package.json"));

var _cli = _interopRequireDefault(require("../cli"));

var _path = _interopRequireDefault(require("path"));

var _prepend = _interopRequireDefault(require("prepend"));

var _util = require("util");

var _ensureCleanLocalGitState = _interopRequireDefault(require("../ensureCleanLocalGitState"));

var _getMergedPullRequests = _interopRequireDefault(require("../getMergedPullRequests"));

var _createChangelog = _interopRequireDefault(require("../createChangelog"));

var _findRemoteAlias = _interopRequireDefault(require("../findRemoteAlias"));

var _gitPromise = _interopRequireDefault(require("git-promise"));

var _getPullRequestLabel = _interopRequireDefault(require("../getPullRequestLabel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander.default.version(_package.default.version).option('--sloppy', 'Skip ensuring clean local git state.').option('--trace', 'Show stack traces for any error.').usage('<version-number>').parse(process.argv); // eslint-disable-next-line no-process-env


const {
  GH_TOKEN
} = process.env;

const changelogPath = _path.default.join(process.cwd(), 'CHANGELOG.md');

const options = {
  sloppy: _commander.default.sloppy,
  changelogPath
};
const findRemoteAlias = (0, _findRemoteAlias.default)({
  git: _gitPromise.default
});
const githubClient = (0, _rest.default)();

if (GH_TOKEN) {
  githubClient.authenticate({
    type: 'token',
    token: GH_TOKEN
  });
}

const getMergedPullRequests = (0, _getMergedPullRequests.default)({
  githubClient,
  git: _gitPromise.default,
  getPullRequestLabel: _getPullRequestLabel.default
});

const getCurrentDate = () => new Date();

const packageInfo = require(_path.default.join(process.cwd(), 'package.json'));

const dependencies = {
  githubClient,
  prependFile: (0, _util.promisify)(_prepend.default),
  packageInfo,
  ensureCleanLocalGitState: (0, _ensureCleanLocalGitState.default)({
    git: _gitPromise.default,
    findRemoteAlias
  }),
  getMergedPullRequests,
  createChangelog: (0, _createChangelog.default)({
    getCurrentDate,
    packageInfo
  })
};
const cliAgent = (0, _cli.default)(dependencies);
cliAgent.run(_commander.default.args[0], options, dependencies).catch(error => {
  let message = `Error: ${error.message}`;

  if (_commander.default.trace) {
    message = error.stack;
  } // eslint-disable-next-line no-console, no-warning-comments


  console.error(message);
  process.exitCode = 1;
});