"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createCliAgent;

var _semver = _interopRequireDefault(require("semver"));

var _getGithubRepo = _interopRequireDefault(require("./getGithubRepo"));

var _validLabels = _interopRequireDefault(require("./validLabels"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function stripTrailingEmptyLine(text) {
  if (text.lastIndexOf('\n\n') === text.length - 2) {
    return text.slice(0, -1);
  }

  return text;
}

function getValidLabels(prLogConfig) {
  if (prLogConfig && prLogConfig.validLabels) {
    return new Map(prLogConfig.validLabels);
  }

  return _validLabels.default;
}

function validateVersionnumber(versionNumber) {
  if (!versionNumber) {
    throw new Error('version-number not specified');
  }

  if (_semver.default.valid(versionNumber) === null) {
    throw new Error('version-number is invalid');
  }
}

function createCliAgent(dependencies) {
  const {
    ensureCleanLocalGitState,
    getMergedPullRequests,
    createChangelog,
    packageInfo,
    prependFile
  } = dependencies;

  async function generateChangelog(options, githubRepo, validLabels, newVersionNumber) {
    if (!options.sloppy) {
      await ensureCleanLocalGitState(githubRepo);
    }

    const pullRequests = await getMergedPullRequests(githubRepo, validLabels);
    const changelog = createChangelog(newVersionNumber, validLabels, pullRequests, githubRepo);
    return stripTrailingEmptyLine(changelog);
  }

  return {
    run: async (newVersionNumber, options = {}) => {
      const githubRepo = (0, _getGithubRepo.default)(packageInfo.repository.url);
      const prLogConfig = packageInfo['pr-log'];
      const validLabels = getValidLabels(prLogConfig);
      validateVersionnumber(newVersionNumber);
      const changelog = await generateChangelog(options, githubRepo, validLabels, newVersionNumber);
      await prependFile(options.changelogPath, changelog);
    }
  };
}