"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _moment = _interopRequireDefault(require("moment"));

var _ramda = _interopRequireDefault(require("ramda"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function formatLinkToPullRequest(pullRequestId, repo) {
  return `[#${pullRequestId}](https://github.com/${repo}/pull/${pullRequestId})`;
}

function formatPullRequest(pullRequest, repo) {
  return `* ${pullRequest.title} (${formatLinkToPullRequest(pullRequest.id, repo)})\n`;
}

function formatListOfPullRequests(pullRequests, repo) {
  return pullRequests.map(pr => formatPullRequest(pr, repo)).join('');
}

function formatSection(displayLabel, pullRequests, repo) {
  return `### ${displayLabel}\n\n${formatListOfPullRequests(pullRequests, repo)}\n`;
}

var _default = ({
  getCurrentDate,
  packageInfo
}) => {
  const defaultDateFormat = 'MMMM D, YYYY';
  const {
    dateFormat = defaultDateFormat
  } = packageInfo['pr-log'] || {};
  return function createChangelog(newVersionNumber, validLabels, mergedPullRequests, repo) {
    const groupedPullRequests = _ramda.default.groupBy(_ramda.default.prop('label'), mergedPullRequests);

    const date = (0, _moment.default)(getCurrentDate()).locale('en').format(dateFormat);
    const title = `## ${newVersionNumber} (${date})`;
    let changelog = `${title}\n\n`;

    for (const [label, displayLabel] of validLabels) {
      const pullRequests = groupedPullRequests[label];

      if (pullRequests) {
        changelog += formatSection(displayLabel, pullRequests, repo);
      }
    }

    return changelog;
  };
};

exports.default = _default;