"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _gitUrlParse = _interopRequireDefault(require("git-url-parse"));

var _ramda = _interopRequireDefault(require("ramda"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function isSameGitUrl(gitUrlA, gitUrlB) {
  const parsedUrlA = (0, _gitUrlParse.default)(gitUrlA);
  const parsedUrlB = (0, _gitUrlParse.default)(gitUrlB);
  const pathA = parsedUrlA.pathname.replace(/\.git$/, '');
  const pathB = parsedUrlB.pathname.replace(/\.git$/, '');
  return parsedUrlA.resource === parsedUrlB.resource && pathA === pathB;
}

function getGitUrl(githubRepo) {
  return `git://github.com/${githubRepo}.git`;
}

var _default = ({
  git
}) => function findRemoteAlias(githubRepo) {
  const gitRemote = getGitUrl(githubRepo);
  return git('remote -v').then(output => {
    const remotes = output.split('\n').map(remote => {
      const tokens = remote.split(/\s/);
      return {
        alias: tokens[0],
        url: tokens[1]
      };
    });

    const matchedRemote = _ramda.default.find(remote => {
      return remote.url && isSameGitUrl(gitRemote, remote.url);
    }, remotes);

    if (!matchedRemote) {
      throw new Error(`This local git repository doesn’t have a remote pointing to ${gitRemote}`);
    }

    return matchedRemote.alias;
  });
};

exports.default = _default;